@@ -29,6 +29,10 @@
 # SOFTWARE.
 ###############################################################################
 
+import glob
+import multiprocessing as mp
+import os
+import re
 import sys
 
 import numpy as np
@@ -36,7 +40,7 @@ import numpy as np
 from spellbook.data_formatting.conduit.python import conduit_bundler as cb
 
 
-WARN = ""
+WARN = None
 try:
     import conduit
     import conduit.relay.io
@@ -44,23 +48,24 @@ except:
     WARN = "\nWARNING: conduit not found."
 
 
-def process_args(args):
-    print(WARN)
-    protocol = cb.determine_protocol(args.output)
+def run(_input, output, schema):
+    if WARN is not None:
+        print(WARN)
+    protocol = cb.determine_protocol(output)
     # Faster loader, just read metadata
-    data_loader = cb.load_node_handle(args.input)
+    data_loader = cb.load_node_handle(_input)
     first_data = conduit.Node()
     data_loader.read(first_data, data_loader.list_child_names()[0])
-    if args.schema == "auto":
+    if schema == "auto":
         schema_json = first_data.to_json()
-    elif "," in args.schema:
-        sub_list = args.schema.split(",")
+    elif "," in schema:
+        sub_list = schema.split(",")
         schema_node = conduit.Node()
         for item in sub_list:
             schema_node[item] = first_data[item]
         schema_json = schema_node.to_json()
     else:
-        with open(args.schema, "r") as f:
+        with open(schema, "r") as f:
             schema_json = f.read()
 
     g = conduit.Generator(schema_json, "json")
@@ -91,10 +96,33 @@ def process_args(args):
         all_dict[dat] = np.vstack(all_dict[dat])
     # Save according to output extension, either numpy or conduit-compatible
     if protocol == "npz":
-        np.savez(args.output, **all_dict)
+        np.savez(output, **all_dict)
     else:
         n = cb.pack_conduit_node_from_dict(all_dict)
-        cb.dump_node(n, args.output)
+        cb.dump_node(n, output)
+
+
+def translate_chunk(chunk, outputs, schema):
+    _chunk_id = re.search("_\d+", chunk)
+    chunk_id = _chunk_id[0]
+    chunk_output = f"{outputs[0]}{chunk_id}{outputs[1]}"
+    run(chunk, chunk_output, schema)
+
+
+def process_args(_input, output, schema, do_chunks, n_processes):
+    if do_chunks:
+        inputs = os.path.splitext(_input)
+        outputs = os.path.splitext(output)
+        if n_processes is None:
+            n_processes = os.cpu_count()
+        pool = mp.Pool(n_processes)
+        chunks = glob.glob(f"{inputs[0]}*{inputs[1]}")
+        for chunk in chunks:
+            pool.apply_async(translate_chunk, args=(chunk, outputs, schema))
+        pool.close()
+        pool.join()
+    else:
+        run(_input, output, schema)
 
 
 def generate_scalar_path_pairs(node, path=""):
