@@ -255,7 +255,7 @@ def define_tests():
         "spellbook serialize": (
             "spellbook serialize --output thing.json --verbose --vars top/middle/bottom=1 top/middle/bottom2=2 top/middle/string=spam top/bool=false top/float=1.3e-9 top/1/junk=nan ; rm thing.json",
             RegexCond(
-                '{"top": {"1": {"junk": NaN}, "bool": true, "float": 1.3e-09, "middle": {"bottom": 1, "bottom2": 2, "string": "spam"}}}'
+                '{"top": {"1": {"junk": NaN}, "bool": false, "float": 1.3e-09, "middle": {"bottom": 1, "bottom2": 2, "string": "spam"}}}'
             ),
         ),
         "spellbook make-samples": (
